@@ -1,4 +1,5 @@
 import json
+import os
 import ssl
 import urllib.error
 import urllib.request
@@ -13,8 +14,7 @@ class BackendIntegrationTest(TestCase):
     """This integration test uses a single instance of the backend proxy
     server for the whole test suite. This makes it quicker, since the server
     isn't restarted between tests, but it also means that the proxy configuration
-    can't be modified once the server has been started. Consider an end2end
-    test if specific proxy configuration is needed.
+    can't be modified once the server has been started.
     """
 
     backend = None
@@ -377,12 +377,13 @@ class BackendIntegrationTest(TestCase):
     def setUpClass(cls):
         cls.backend = backend.create()
         cls.configure_proxy(*cls.backend.address()[:2])
-        cls.httpbin = testutils.get_httpbin()
+        cls.httpbin = testutils.Httpbin() if os.name != 'nt' else 'https://httpbin.org'
 
     @classmethod
     def tearDownClass(cls):
         cls.backend.shutdown()
-        cls.httpbin.close()
+        if os.name != 'nt':
+            cls.httpbin.shutdown()
 
     def tearDown(self):
         del self.backend.modifier.headers
